import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { I as Item, B as BulkCreateProjectItemsOptions, a as BulkCreateProjectItemsResponse, L as ListProjectItemsOptions, b as ListProjectItemsResponse, U as UpdateProjectItem, c as BulkUpdateProjectItemsOptions, d as BulkUpdateProjectItemsResponse, D as DeleteProjectItemResponse, e as BulkDeleteProjectItemsOptions, f as BulkDeleteProjectItemsResponse, g as DuplicateProjectItemsOptions, h as DuplicateProjectItemsResponse, G as GenerateTokenForProjectItemsResponse, P as ProjectItemCreatedEnvelope, i as ProjectItemDeletedEnvelope, j as ProjectItemUpdatedEnvelope } from './portfolio-project-items-v1-project-item-project-items.universal-BMVN9bZC.mjs';
export { ah as ActionEvent, A as App, H as ApplicationError, aq as BaseEventMetadata, J as BulkActionMetadata, z as BulkCreateProjectItemResult, y as BulkCreateProjectItemsRequest, a8 as BulkDeleteProjectItemResult, a7 as BulkDeleteProjectItemsRequest, a5 as BulkUpdateProjectItemResult, a3 as BulkUpdateProjectItemsRequest, a9 as CreateProjectGalleryRequest, aa as CreateProjectGalleryResponse, w as CreateProjectItemRequest, x as CreateProjectItemResponse, $ as CursorPaging, R as Cursors, C as CustomTag, a6 as DeleteProjectItemRequest, aj as DeletedProjectRestored, ab as DomainEvent, ac as DomainEventBodyOneOf, ak as DuplicateProjectItemsRequest, ai as Empty, ad as EntityCreatedEvent, ag as EntityDeletedEvent, af as EntityUpdatedEvent, ar as EventMetadata, F as File, ao as GenerateTokenForProjectItemsRequest, K as GetProjectItemRequest, M as GetProjectItemResponse, am as IdentificationData, an as IdentificationDataIdOneOf, m as Image, k as ImageType, s as InvalidateCache, t as InvalidateCacheGetByOneOf, E as ItemMetadata, l as ItemMetadataOneOf, r as Link, N as ListProjectItemsRequest, a4 as MaskedItem, al as MessageEnvelope, u as Page, O as Paging, Q as PagingMetadataV2, n as Point, ap as ProjectItemMediaToken, X as QueryProjectItemsRequest, a0 as QueryProjectItemsResponse, Y as QueryV2, Z as QueryV2PagingMethodOneOf, ae as RestoreInfo, S as SortOrder, _ as Sorting, q as Tags, T as Type, v as URI, o as UnsharpMasking, a1 as UpdateProjectItemRequest, a2 as UpdateProjectItemResponse, V as Video, p as VideoResolution, W as WebhookIdentityType } from './portfolio-project-items-v1-project-item-project-items.universal-BMVN9bZC.mjs';

declare function createProjectItem$1(httpClient: HttpClient): CreateProjectItemSignature;
interface CreateProjectItemSignature {
    /**
     * Creates a project item.
     * @param - Project item to create.
     * @returns Newly created project item.
     */
    (item: Item): Promise<Item>;
}
declare function bulkCreateProjectItems$1(httpClient: HttpClient): BulkCreateProjectItemsSignature;
interface BulkCreateProjectItemsSignature {
    /**
     * Creates multiple project items.
     */
    (options?: BulkCreateProjectItemsOptions | undefined): Promise<BulkCreateProjectItemsResponse>;
}
declare function getProjectItem$1(httpClient: HttpClient): GetProjectItemSignature;
interface GetProjectItemSignature {
    /**
     * Retrieves a project item.
     * @param - Project item ID.
     * @returns Project item.
     */
    (itemId: string): Promise<Item>;
}
declare function listProjectItems$1(httpClient: HttpClient): ListProjectItemsSignature;
interface ListProjectItemsSignature {
    /**
     * Retrieves a list of all project items in the specified project.
     * @param - Project ID.
     */
    (projectId: string, options?: ListProjectItemsOptions | undefined): Promise<ListProjectItemsResponse>;
}
declare function updateProjectItem$1(httpClient: HttpClient): UpdateProjectItemSignature;
interface UpdateProjectItemSignature {
    /**
     * Updates a project item.
     * @param - Project item ID.
     * @returns The updated project item.
     */
    (_id: string, item: UpdateProjectItem): Promise<Item>;
}
declare function bulkUpdateProjectItems$1(httpClient: HttpClient): BulkUpdateProjectItemsSignature;
interface BulkUpdateProjectItemsSignature {
    /**
     * Updates multiple project items.
     */
    (options?: BulkUpdateProjectItemsOptions | undefined): Promise<BulkUpdateProjectItemsResponse>;
}
declare function deleteProjectItem$1(httpClient: HttpClient): DeleteProjectItemSignature;
interface DeleteProjectItemSignature {
    /**
     * Deletes a project item.
     * @param - ID of the project item to delete.
     */
    (itemId: string): Promise<DeleteProjectItemResponse>;
}
declare function bulkDeleteProjectItems$1(httpClient: HttpClient): BulkDeleteProjectItemsSignature;
interface BulkDeleteProjectItemsSignature {
    /**
     * Deletes multiple project items.
     */
    (options: BulkDeleteProjectItemsOptions): Promise<BulkDeleteProjectItemsResponse>;
}
declare function duplicateProjectItems$1(httpClient: HttpClient): DuplicateProjectItemsSignature;
interface DuplicateProjectItemsSignature {
    /**
     * Duplicates project items from one project (the origin) to another project (the target).
     *
     * <blockquote class="important">
     * <strong>Important:</strong>
     *
     * Both the origin and target projects must exist before calling this method.
     * </blockquote>
     * @param - ID of the project containing the items to duplicate.
     */
    (originProjectId: string, options: DuplicateProjectItemsOptions): Promise<DuplicateProjectItemsResponse>;
}
declare function generateTokenForProjectItems$1(httpClient: HttpClient): GenerateTokenForProjectItemsSignature;
interface GenerateTokenForProjectItemsSignature {
    /**
     * Generate media token for project items
     * @param - Media ids of requested project items
     */
    (mediaIds: string[]): Promise<GenerateTokenForProjectItemsResponse>;
}
declare const onProjectItemCreated$1: EventDefinition<ProjectItemCreatedEnvelope, "wix.portfolio.project_items.v1.project_item_created">;
declare const onProjectItemDeleted$1: EventDefinition<ProjectItemDeletedEnvelope, "wix.portfolio.project_items.v1.project_item_deleted">;
declare const onProjectItemUpdated$1: EventDefinition<ProjectItemUpdatedEnvelope, "wix.portfolio.project_items.v1.project_item_updated">;

declare const createProjectItem: MaybeContext<BuildRESTFunction<typeof createProjectItem$1> & typeof createProjectItem$1>;
declare const bulkCreateProjectItems: MaybeContext<BuildRESTFunction<typeof bulkCreateProjectItems$1> & typeof bulkCreateProjectItems$1>;
declare const getProjectItem: MaybeContext<BuildRESTFunction<typeof getProjectItem$1> & typeof getProjectItem$1>;
declare const listProjectItems: MaybeContext<BuildRESTFunction<typeof listProjectItems$1> & typeof listProjectItems$1>;
declare const updateProjectItem: MaybeContext<BuildRESTFunction<typeof updateProjectItem$1> & typeof updateProjectItem$1>;
declare const bulkUpdateProjectItems: MaybeContext<BuildRESTFunction<typeof bulkUpdateProjectItems$1> & typeof bulkUpdateProjectItems$1>;
declare const deleteProjectItem: MaybeContext<BuildRESTFunction<typeof deleteProjectItem$1> & typeof deleteProjectItem$1>;
declare const bulkDeleteProjectItems: MaybeContext<BuildRESTFunction<typeof bulkDeleteProjectItems$1> & typeof bulkDeleteProjectItems$1>;
declare const duplicateProjectItems: MaybeContext<BuildRESTFunction<typeof duplicateProjectItems$1> & typeof duplicateProjectItems$1>;
declare const generateTokenForProjectItems: MaybeContext<BuildRESTFunction<typeof generateTokenForProjectItems$1> & typeof generateTokenForProjectItems$1>;
/**
 * Triggered when a project item is created.
 */
declare const onProjectItemCreated: BuildEventDefinition<typeof onProjectItemCreated$1>;
/**
 * Triggered when a project item is deleted.
 */
declare const onProjectItemDeleted: BuildEventDefinition<typeof onProjectItemDeleted$1>;
/**
 * Triggered when a project item is updated.
 */
declare const onProjectItemUpdated: BuildEventDefinition<typeof onProjectItemUpdated$1>;

export { BulkCreateProjectItemsOptions, BulkCreateProjectItemsResponse, BulkDeleteProjectItemsOptions, BulkDeleteProjectItemsResponse, BulkUpdateProjectItemsOptions, BulkUpdateProjectItemsResponse, DeleteProjectItemResponse, DuplicateProjectItemsOptions, DuplicateProjectItemsResponse, GenerateTokenForProjectItemsResponse, Item, ListProjectItemsOptions, ListProjectItemsResponse, ProjectItemCreatedEnvelope, ProjectItemDeletedEnvelope, ProjectItemUpdatedEnvelope, UpdateProjectItem, bulkCreateProjectItems, bulkDeleteProjectItems, bulkUpdateProjectItems, createProjectItem, deleteProjectItem, duplicateProjectItems, generateTokenForProjectItems, getProjectItem, listProjectItems, onProjectItemCreated, onProjectItemDeleted, onProjectItemUpdated, updateProjectItem };
