import { w as CreateProjectItemRequest$1, x as CreateProjectItemResponse$1, y as BulkCreateProjectItemsRequest$1, a as BulkCreateProjectItemsResponse$1, K as GetProjectItemRequest$1, M as GetProjectItemResponse$1, N as ListProjectItemsRequest$1, b as ListProjectItemsResponse$1, a1 as UpdateProjectItemRequest$1, a2 as UpdateProjectItemResponse$1, a3 as BulkUpdateProjectItemsRequest$1, d as BulkUpdateProjectItemsResponse$1, a6 as DeleteProjectItemRequest$1, D as DeleteProjectItemResponse$1, a7 as BulkDeleteProjectItemsRequest$1, f as BulkDeleteProjectItemsResponse$1, ak as DuplicateProjectItemsRequest$1, h as DuplicateProjectItemsResponse$1, ao as GenerateTokenForProjectItemsRequest$1, G as GenerateTokenForProjectItemsResponse$1 } from './portfolio-project-items-v1-project-item-project-items.universal-BMVN9bZC.mjs';

interface Item extends ItemMetadataOneOf {
    /** Information about the Wix Media image. */
    image?: Image;
    /** Information about the Wix Media video. */
    video?: Video;
    /**
     * Project ID.
     * @format GUID
     */
    projectId?: string | null;
    /**
     * Project item ID.
     * @readonly
     * @format GUID
     */
    id?: string | null;
    /**
     * Index that determines which position a project is displayed in the project.  <br />
     *
     * Default: [Epoch](https://www.epoch101.com/) timestamp. <br />
     */
    sortOrder?: number | null;
    /** Project item title. */
    title?: string | null;
    /** Project item description. */
    description?: string | null;
    /**
     * Project item data type.
     * @readonly
     */
    type?: TypeWithLiterals;
    /**
     * Date and time the project item was created.
     * @readonly
     */
    createdDate?: Date | null;
    /**
     * Date and time the project item was last updated.
     * @readonly
     */
    updatedDate?: Date | null;
    /** Project item link. */
    link?: Link;
}
/** @oneof */
interface ItemMetadataOneOf {
    /** Information about the Wix Media image. */
    image?: Image;
    /** Information about the Wix Media video. */
    video?: Video;
}
declare enum Type {
    /** Undefined item type. */
    UNDEFINED = "UNDEFINED",
    /** Image item type. */
    IMAGE = "IMAGE",
    /** Video item type. */
    VIDEO = "VIDEO"
}
/** @enumType */
type TypeWithLiterals = Type | 'UNDEFINED' | 'IMAGE' | 'VIDEO';
interface Image {
    /** Information about the Wix Media image. */
    imageInfo?: CommonImage;
    /** Focal point of the image. */
    focalPoint?: Point;
}
interface CommonImage {
    /** WixMedia image ID. Required. */
    id?: string;
    /**
     * Image URL.
     * @readonly
     */
    url?: string;
    /** Original image height. Required. */
    height?: number;
    /** Original image width. Required. */
    width?: number;
    /** Image alt text. */
    altText?: string | null;
    /** Image filename. */
    filename?: string | null;
}
interface Point {
    /** X-coordinate of the focal point. */
    x?: number;
    /** Y-coordinate of the focal point. */
    y?: number;
}
interface Video {
    /** Information about the Wix Media video. */
    videoInfo?: VideoV2;
    /** Manually defined Video duration in milliseconds. */
    durationInMillis?: number | null;
}
interface VideoV2 {
    /** WixMedia ID. Required. */
    id?: string;
    /** Video URL. */
    url?: string;
    /**
     * Available resolutions for the video, starting with the optimal resolution.
     * @maxSize 100
     */
    resolutions?: VideoResolution[];
    /** Video filename. */
    filename?: string | null;
    /** Video posters. */
    posters?: CommonImage[];
}
interface VideoResolution {
    /** Video URL.  Required. */
    url?: string;
    /** Video height. Required. */
    height?: number;
    /** Video width.  Required. */
    width?: number;
    /** Video format for example, mp4, hls.  Required. */
    format?: string;
    /** Video quality for example 480p, 720p. */
    quality?: string | null;
    /** Video filename. */
    filename?: string | null;
}
interface Link {
    /** Display text of the link. */
    text?: string | null;
    /**
     * Target URL of the link.
     * @format WEB_URL
     */
    url?: string | null;
    /**
     * Whether the link opens in a new tab or window. One of:
     * * `'_blank'`: The link opens in a new tab or window.
     * * `'_self'`: The link opens in the same tab or window.
     * @maxLength 50
     */
    target?: string | null;
}
interface CreateProjectItemRequest {
    /** Project item to create. */
    item: Item;
}
interface CreateProjectItemResponse {
    /** Newly created project item. */
    item?: Item;
}
interface BulkCreateProjectItemsRequest {
    /**
     * Project items to create.
     * @minSize 1
     * @maxSize 1000
     */
    items: Item[];
    /** Whether to include the created project items in the response. Set to `true` to receive the project items in the response. Default: `false` */
    returnFullEntity?: boolean | null;
}
interface BulkCreateProjectItemsResponse {
    /** Project items created by bulk action. */
    results?: BulkCreateProjectItemResult[];
    /** Bulk action metadata. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkCreateProjectItemResult {
    /** Information about successful action or error for failure. */
    itemMetadata?: ItemMetadata;
    /** Newly created project item. */
    item?: Item;
}
interface ItemMetadata {
    /** Item ID. Should always be available, unless it's impossible (for example, when failing to create an item). */
    id?: string | null;
    /** Index of the item within the request array. Allows for correlation between request and response items. */
    originalIndex?: number;
    /** Whether the requested action was successful for this item. When `false`, the `error` field is populated. */
    success?: boolean;
    /** Details about the error in case of failure. */
    error?: ApplicationError;
}
interface ApplicationError {
    /** Error code. */
    code?: string;
    /** Description of the error. */
    description?: string;
    /** Data related to the error. */
    data?: Record<string, any> | null;
}
interface BulkActionMetadata {
    /** Number of items that were successfully processed. */
    totalSuccesses?: number;
    /** Number of items that couldn't be processed. */
    totalFailures?: number;
    /** Number of failures without details because detailed failure threshold was exceeded. */
    undetailedFailures?: number;
}
interface GetProjectItemRequest {
    /**
     * Project item ID.
     * @format GUID
     */
    itemId: string;
}
interface GetProjectItemResponse {
    /** Project item. */
    item?: Item;
}
interface ListProjectItemsRequest {
    /**
     * Project ID.
     * @format GUID
     */
    projectId: string;
    /** Maximum number of items to return in the results. */
    paging?: Paging;
}
interface Paging {
    /** Number of items to load. */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface ListProjectItemsResponse {
    /** Project items. */
    items?: Item[];
    /**
     * @deprecated
     * @targetRemovalDate 2025-05-25
     */
    pagingMetadataV2?: PagingMetadataV2;
    /** Paging metadata. */
    metadata?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}
interface UpdateProjectItemRequest {
    /** The project item to update. */
    item: Item;
}
interface UpdateProjectItemResponse {
    /** The updated project item. */
    item?: Item;
}
interface BulkUpdateProjectItemsRequest {
    /**
     * items to be updated.
     * @maxSize 100
     */
    items?: MaskedItem[];
    /** Whether to include the updated project items in the response. Set to `true` to receive the project items in the response. Default: `false` */
    returnFullEntity?: boolean | null;
}
interface MaskedItem {
    /** Item to be updated. */
    item?: Item;
}
interface BulkUpdateProjectItemsResponse {
    /** Project items updated by bulk action. */
    results?: BulkUpdateProjectItemResult[];
    /** Bulk action metadata. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkUpdateProjectItemResult {
    /** Information about successful action or error for failure. */
    itemMetadata?: ItemMetadata;
    /** Updated project item. */
    item?: Item;
}
interface DeleteProjectItemRequest {
    /**
     * ID of the project item to delete.
     * @format GUID
     */
    itemId: string;
}
interface DeleteProjectItemResponse {
    /**
     * Project ID.
     * @format GUID
     */
    projectId?: string;
    /**
     * ID of the deleted project item.
     * @format GUID
     */
    itemId?: string;
}
interface BulkDeleteProjectItemsRequest {
    /**
     * Project item IDs.
     * @format GUID
     * @minSize 1
     * @maxLength 100
     */
    itemIds: string[];
}
interface BulkDeleteProjectItemsResponse {
    /** Project items deleted by bulk action. */
    results?: BulkDeleteProjectItemResult[];
    /** Bulk action metadata. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface BulkDeleteProjectItemResult {
    /** Information about successful action or error for failure. */
    itemMetadata?: ItemMetadata;
    /**
     * Project item ID.
     * @format GUID
     */
    itemId?: string;
}
interface DuplicateProjectItemsRequest {
    /**
     * ID of the project containing the items to duplicate.
     * @format GUID
     */
    originProjectId: string;
    /**
     * ID of the project where the duplicated items will be added.
     * @format GUID
     */
    targetProjectId: string;
}
interface DuplicateProjectItemsResponse {
    /**
     * Project ID where the duplicated items have been added.
     * @format GUID
     */
    projectId?: string;
    /** Bulk action metadata. */
    bulkActionMetadata?: BulkActionMetadata;
}
interface GenerateTokenForProjectItemsRequest {
    /**
     * Media ids of requested project items
     * @minSize 1
     * @maxLength 100
     */
    mediaIds: string[];
}
interface GenerateTokenForProjectItemsResponse {
    /** Generated media tokens for project items */
    mediaTokens?: ProjectItemMediaToken[];
}
interface ProjectItemMediaToken {
    /** Media id of project item */
    mediaId?: string;
    /** Generated media token for project item */
    mediaToken?: string;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function createProjectItem(): __PublicMethodMetaInfo<'POST', {}, CreateProjectItemRequest$1, CreateProjectItemRequest, CreateProjectItemResponse$1, CreateProjectItemResponse>;
declare function bulkCreateProjectItems(): __PublicMethodMetaInfo<'POST', {}, BulkCreateProjectItemsRequest$1, BulkCreateProjectItemsRequest, BulkCreateProjectItemsResponse$1, BulkCreateProjectItemsResponse>;
declare function getProjectItem(): __PublicMethodMetaInfo<'GET', {
    itemId: string;
}, GetProjectItemRequest$1, GetProjectItemRequest, GetProjectItemResponse$1, GetProjectItemResponse>;
declare function listProjectItems(): __PublicMethodMetaInfo<'GET', {
    projectId: string;
}, ListProjectItemsRequest$1, ListProjectItemsRequest, ListProjectItemsResponse$1, ListProjectItemsResponse>;
declare function updateProjectItem(): __PublicMethodMetaInfo<'PATCH', {
    itemId: string;
}, UpdateProjectItemRequest$1, UpdateProjectItemRequest, UpdateProjectItemResponse$1, UpdateProjectItemResponse>;
declare function bulkUpdateProjectItems(): __PublicMethodMetaInfo<'PATCH', {}, BulkUpdateProjectItemsRequest$1, BulkUpdateProjectItemsRequest, BulkUpdateProjectItemsResponse$1, BulkUpdateProjectItemsResponse>;
declare function deleteProjectItem(): __PublicMethodMetaInfo<'DELETE', {
    itemId: string;
}, DeleteProjectItemRequest$1, DeleteProjectItemRequest, DeleteProjectItemResponse$1, DeleteProjectItemResponse>;
declare function bulkDeleteProjectItems(): __PublicMethodMetaInfo<'DELETE', {}, BulkDeleteProjectItemsRequest$1, BulkDeleteProjectItemsRequest, BulkDeleteProjectItemsResponse$1, BulkDeleteProjectItemsResponse>;
declare function duplicateProjectItems(): __PublicMethodMetaInfo<'POST', {}, DuplicateProjectItemsRequest$1, DuplicateProjectItemsRequest, DuplicateProjectItemsResponse$1, DuplicateProjectItemsResponse>;
declare function generateTokenForProjectItems(): __PublicMethodMetaInfo<'POST', {}, GenerateTokenForProjectItemsRequest$1, GenerateTokenForProjectItemsRequest, GenerateTokenForProjectItemsResponse$1, GenerateTokenForProjectItemsResponse>;

export { type __PublicMethodMetaInfo, bulkCreateProjectItems, bulkDeleteProjectItems, bulkUpdateProjectItems, createProjectItem, deleteProjectItem, duplicateProjectItems, generateTokenForProjectItems, getProjectItem, listProjectItems, updateProjectItem };
